@@ -1,6 +1,7 @@
 
 #include "../Common/Common.h"
 
+#include <cstring>
 #include "FileLogger.h"
 
 // Track memory leaks on Windows to the line that new'd the memory
@@ -511,7 +512,7 @@ std::string CFileLogger::GetTimeDateStamp()
     szTimeLine = ctime(&(sTimeBuffer.time));
 #else
     gettimeofday(&sTimeBuffer, &sTimezoneBuffer);
-    szTimeLine = ctime(&(sTimeBuffer.tv_sec));
+    szTimeLine = ctime((const time_t *)&(sTimeBuffer.tv_sec));
 #endif
  
     // Format is:
@@ -538,7 +539,7 @@ std::string CFileLogger::GetTimeDateStamp()
 #ifdef _WIN32
         sprintf(strMs, "%d", sTimeBuffer.millitm);
 #else
-        sprintf(strMs, "%d", sTimeBuffer.tv_usec / 1000);
+        sprintf(strMs, "%d", static_cast<int>(sTimeBuffer.tv_usec / 1000));
 #endif
         if (strlen(strMs) == 1)
           strTimeStamp += "00";
