@@ -1,14 +1,35 @@
+// GtkDasherControl.cpp
+//
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
 #include "../Common/Common.h"
 
+#include "DasherControl.h"
+#include "GtkDasherControl.h"
+#include "custom_marshal.h"
+#include "game_mode_helper.h"
+
 #include <gtk/gtkmarshal.h>
 
-#include "GtkDasherControl.h"
-//#include "game_mode_helper.h"
-#include "DasherControl.h"
-#include "custom_marshal.h"
-
 struct _GtkDasherControlPrivate {
   CDasherControl *pControl;
+  void* pGameHelper;
 };
 
 typedef struct _GtkDasherControlPrivate GtkDasherControlPrivate;
@@ -39,7 +60,7 @@ G_DEFINE_TYPE(GtkDasherControl, gtk_dasher_control, GTK_TYPE_VBOX);
 
 static void gtk_dasher_control_finalize(GObject * pObject);
 
-static guint gtk_dasher_control_signals[SIGNAL_NUM]; /* TODO: initilaise this? */
+static guint gtk_dasher_control_signals[SIGNAL_NUM]; /* TODO: initialise this? */
 
 static void 
 gtk_dasher_control_class_init(GtkDasherControlClass *pClass) {
@@ -181,13 +202,11 @@ gtk_dasher_control_get_allowed_values(GtkDasherControl *pControl, int iParameter
 void 
 gtk_dasher_control_train(GtkDasherControl *pControl, const gchar *szFilename) {
   GtkDasherControlPrivate *pPrivate = GTK_DASHER_CONTROL_GET_PRIVATE(pControl);
-  pPrivate->pControl->Train(szFilename);
+  pPrivate->pControl->ImportTrainingText(szFilename);
 };
 
 void 
 gtk_dasher_control_set_context(GtkDasherControl *pControl, const gchar *szContext) {
-  
-
   GtkDasherControlPrivate *pPrivate = GTK_DASHER_CONTROL_GET_PRIVATE(pControl);
   pPrivate->pControl->SetContext(szContext);
 }
@@ -283,10 +302,17 @@ gtk_dasher_control_game_messagein(GtkDasherControl *pControl, int message, void*
 }
 
 void 
-gtk_dasher_control_game_messageout(GtkDasherControl *pControl, void* gameHelper, int message, const void* messagedata) {
+gtk_dasher_control_game_helperreg(GtkDasherControl *pControl, void* gameHelper) {
   GtkDasherControlPrivate *pPrivate = GTK_DASHER_CONTROL_GET_PRIVATE(pControl);
-  //  GameModeHelper* pHelper = GAME_MODE_HELPER(gameHelper);
-  //game_mode_helper_message(pHelper, message, messagedata);
+  pPrivate->pGameHelper = gameHelper;
+}
+
+void 
+gtk_dasher_control_game_messageout(GtkDasherControl *pControl, int message, const void* messagedata) {
+  GtkDasherControlPrivate *pPrivate = GTK_DASHER_CONTROL_GET_PRIVATE(pControl);
+  GameModeHelper* pHelper = GAME_MODE_HELPER(pPrivate->pGameHelper);
+  if(pHelper)
+    game_mode_helper_message(pHelper, message, messagedata);
 }
 
 void 
