@@ -38,8 +38,7 @@ static menuentry menutable[] = {
   {BP_STOP_IDLE, IDC_STOPIDLE},
   {BP_PAUSE_OUTSIDE, IDC_WINDOWPAUSE},
   {BP_AUTO_SPEEDCONTROL, IDC_AUTOSPEED},
-  {BP_AUTOCALIBRATE, IDC_AUTOCALIBRATE},
-  {BP_CONTROL_MODE, IDC_CONTROLMODE}
+  {BP_AUTOCALIBRATE, IDC_AUTOCALIBRATE}
 };
 
 static menuentry listtable[] = {
@@ -119,12 +118,51 @@ void CControlPage::PopulateList() {
         SendMessage(GetDlgItem(m_hwnd, listtable[i].idcNum), LB_SETCURSEL, iIdx, 0);
     }
   }
+
+// TODO: Pretty horrible - sort this out
+  {
+        //CButtonPrefs ButtonPrefs(m_hwnd, 0, m_pAppSettings);
+        int iSelection(SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETCURSEL, 0, 0));
+    
+        int iLength(SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETTEXTLEN, iSelection, 0));
+        TCHAR *szData(new TCHAR[iLength + 1]);
+        SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETTEXT, iSelection, (LPARAM)szData);
+
+        std::string strNewValue;
+        WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+        delete[] szData;
+
+        SModuleSettings *pSettings;
+        int iSettingsCount;
+
+        EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS), m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount));
+      }
+      
+      {
+        int iSelection(SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETCURSEL, 0, 0));
+    
+		if(iSelection != LB_ERR) {
+			int iLength(SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETTEXTLEN, iSelection, 0));
+			TCHAR *szData(new TCHAR[iLength + 1]);
+			SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETTEXT, iSelection, (LPARAM)szData);
+
+			std::string strNewValue;
+			WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+			delete[] szData;
+
+	        SModuleSettings *pSettings;
+			int iSettingsCount;
+
+			EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS2), m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount));
+		}
+		else {
+			EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS2), false);
+		}
+      }
+      
+
 }
 
-bool CControlPage::Validate() {
-  // Return false if something is wrong to prevent user from clicking to a different page. Please also pop up a dialogue informing the user at this point.
-  return TRUE;
-}
 
 bool CControlPage::Apply() 
 {
@@ -185,11 +223,12 @@ bool CControlPage::Apply()
 }
 
 LRESULT CControlPage::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam) {
-
+  // TODO: Why isn't this in case?
   if(message == WM_MS_CLOSE) {
     if(m_pModuleSettingsDialogue) {
       m_pModuleSettingsDialogue->DestroyWindow();
     }
+
     m_pModuleSettingsDialogue = NULL;
     EnableWindow(m_hwnd, true);
     return 0;
@@ -201,62 +240,110 @@ LRESULT CControlPage::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) 
 		{
-		case (IDC_DISPLAY):
-			break;
+	/*	case (IDC_DISPLAY):
+			break;*/
+    case IDC_CONTROL_LIST:
+      {
+        int iSelection(SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETCURSEL, 0, 0));
+
+        if(iSelection != LB_ERR) {    
+          int iLength(SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETTEXTLEN, iSelection, 0));
+          TCHAR *szData(new TCHAR[iLength + 1]);
+          SendMessage(GetDlgItem(m_hwnd, IDC_CONTROL_LIST), LB_GETTEXT, iSelection, (LPARAM)szData);
+  
+          std::string strNewValue;
+          WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+          delete[] szData;
+  
+          SModuleSettings *pSettings;
+          int iSettingsCount;
+
+          EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS), m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount));
+        }
+        else {
+          EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS), false);
+        }
+      }
+      break;
+    case IDC_INPUT_LIST:
+      {
+        int iSelection(SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETCURSEL, 0, 0));
+    
+	    	if(iSelection != LB_ERR) {
+          int iLength(SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETTEXTLEN, iSelection, 0));
+          TCHAR *szData(new TCHAR[iLength + 1]);
+          SendMessage(GetDlgItem(m_hwnd, IDC_INPUT_LIST), LB_GETTEXT, iSelection, (LPARAM)szData);
+
+          std::string strNewValue;
+          WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+          delete[] szData;
+
+          SModuleSettings *pSettings;
+          int iSettingsCount;
+
+          EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS2), m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount));
+        }
+        else {
+          EnableWindow(GetDlgItem(m_hwnd, IDC_BUTTON_PREFS2), false);
+        }
+      }
+      break;
     case IDC_BUTTON_PREFS: 
       {
-        //CButtonPrefs ButtonPrefs(m_hwnd, 0, m_pAppSettings);
         int iSelection(SendMessage(GetDlgItem(m_hwnd, listtable[0].idcNum), LB_GETCURSEL, 0, 0));
-    
-        int iLength(SendMessage(GetDlgItem(m_hwnd, listtable[0].idcNum), LB_GETTEXTLEN, iSelection, 0));
-        TCHAR *szData(new TCHAR[iLength + 1]);
-        SendMessage(GetDlgItem(m_hwnd, listtable[0].idcNum), LB_GETTEXT, iSelection, (LPARAM)szData);
+      
+        if(iSelection != LB_ERR) {
+          int iLength(SendMessage(GetDlgItem(m_hwnd, listtable[0].idcNum), LB_GETTEXTLEN, iSelection, 0));
+          TCHAR *szData(new TCHAR[iLength + 1]);
+          SendMessage(GetDlgItem(m_hwnd, listtable[0].idcNum), LB_GETTEXT, iSelection, (LPARAM)szData);
 
-        std::string strNewValue;
-        WinUTF8::wstring_to_UTF8string(szData, strNewValue);
-        delete[] szData;
+          std::string strNewValue;
+          WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+          delete[] szData;
 
-        SModuleSettings *pSettings;
-        int iSettingsCount;
+          SModuleSettings *pSettings;
+          int iSettingsCount;
 
-        if(!m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount))
-          break;
+          if(!m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount))
+            break;
 
-        RECT sRect;
+          RECT sRect;
 
-        m_pModuleSettingsDialogue = new CModuleSettings(strNewValue, pSettings, iSettingsCount, m_pDasherInterface);
-        m_pModuleSettingsDialogue->Create(m_hwnd, &sRect);
-        m_pModuleSettingsDialogue->ShowWindow(SW_RESTORE);
+          m_pModuleSettingsDialogue = new CModuleSettings(strNewValue, pSettings, iSettingsCount, m_pDasherInterface);
+          m_pModuleSettingsDialogue->Create(m_hwnd, &sRect);
+          m_pModuleSettingsDialogue->ShowWindow(SW_RESTORE);
         
-        EnableWindow(m_hwnd, false);
+          EnableWindow(m_hwnd, false);
+        }
       }
 		  break;
     case IDC_BUTTON_PREFS2: 
       {
-        //CButtonPrefs ButtonPrefs(m_hwnd, 0, m_pAppSettings);
         int iSelection(SendMessage(GetDlgItem(m_hwnd, listtable[1].idcNum), LB_GETCURSEL, 0, 0));
     
-        int iLength(SendMessage(GetDlgItem(m_hwnd, listtable[1].idcNum), LB_GETTEXTLEN, iSelection, 0));
-        TCHAR *szData(new TCHAR[iLength + 1]);
-        SendMessage(GetDlgItem(m_hwnd, listtable[1].idcNum), LB_GETTEXT, iSelection, (LPARAM)szData);
+        if(iSelection != LB_ERR) {
+          int iLength(SendMessage(GetDlgItem(m_hwnd, listtable[1].idcNum), LB_GETTEXTLEN, iSelection, 0));
+          TCHAR *szData(new TCHAR[iLength + 1]);
+          SendMessage(GetDlgItem(m_hwnd, listtable[1].idcNum), LB_GETTEXT, iSelection, (LPARAM)szData);
 
-        std::string strNewValue;
-        WinUTF8::wstring_to_UTF8string(szData, strNewValue);
-        delete[] szData;
+          std::string strNewValue;
+          WinUTF8::wstring_to_UTF8string(szData, strNewValue);
+          delete[] szData;
 
-        SModuleSettings *pSettings;
-        int iSettingsCount;
+          SModuleSettings *pSettings;
+          int iSettingsCount;
 
-        if(!m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount))
-          break;
+          if(!m_pDasherInterface->GetModuleSettings(strNewValue, &pSettings, &iSettingsCount))
+            break;
 
-        RECT sRect;
+          RECT sRect;
 
-        m_pModuleSettingsDialogue = new CModuleSettings(strNewValue, pSettings, iSettingsCount, m_pDasherInterface);
-        m_pModuleSettingsDialogue->Create(m_hwnd, &sRect);
-        m_pModuleSettingsDialogue->ShowWindow(SW_RESTORE);
+          m_pModuleSettingsDialogue = new CModuleSettings(strNewValue, pSettings, iSettingsCount, m_pDasherInterface);
+          m_pModuleSettingsDialogue->Create(m_hwnd, &sRect);
+          m_pModuleSettingsDialogue->ShowWindow(SW_RESTORE);
         
-        EnableWindow(m_hwnd, false);
+          EnableWindow(m_hwnd, false);
+        }
       }
 		  break;
 		case IDC_STOPIDLE:
@@ -287,5 +374,5 @@ LRESULT CControlPage::WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM l
 
         }
         // pass on to superclass:
-        return CPrefsPageBase::WndProc(Window, message, wParam, lParam);
+  return CPrefsPageBase::WndProc(Window, message, wParam, lParam);
 }
