@@ -24,18 +24,14 @@ protected:
   LRESULT WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam);
 private:
   
-  HWND slider;
-  HWND uniformbox;
-
-  TCHAR m_tcBuffer[1000];
-
+ 
 
   // Some status flags:
   void PopulateList();
   void InitCustomBox();
   bool UpdateInfo();
    bool Apply();
-  bool Validate();
+ 
 };
 
 #endif  /* #ifndef __AlphabetBox_h__ */
