@@ -15,7 +15,7 @@
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -38,7 +38,9 @@ SToolbarButton sButtons[] = {
   {STD_CUT, 3, IDS_EDIT_CUT, ID_EDIT_CUT},
   {STD_COPY, 4, IDS_EDIT_COPY, ID_EDIT_COPY},
   {-2, 5, IDS_EDIT_COPY_ALL, ID_EDIT_COPY_ALL},
-  {STD_PASTE, 6, IDS_EDIT_PASTE, ID_EDIT_PASTE}
+  {STD_PASTE, 6, IDS_EDIT_PASTE, ID_EDIT_PASTE},
+  {-1, -1, 0, 0},
+  {STD_PROPERTIES, 7, IDS_OPTIONS_PREFS, ID_OPTIONS_PREFS}
 };
 
 CToolbar::CToolbar(HWND hParent, bool bVisible) {
@@ -85,7 +87,11 @@ void CToolbar::CreateToolbar() {
   REBARBANDINFO rbBand;
   rbBand.cbSize = sizeof(REBARBANDINFO); 
   rbBand.fMask  = RBBIM_STYLE | RBBIM_CHILD  | RBBIM_CHILDSIZE;
+#ifndef _WIN32_WCE
   rbBand.fStyle = RBBS_CHILDEDGE | RBBS_FIXEDBMP | RBBS_GRIPPERALWAYS | RBBS_USECHEVRON;
+#else
+  rbBand.fStyle = RBBS_CHILDEDGE | RBBS_FIXEDBMP | RBBS_GRIPPERALWAYS;
+#endif
  
   // Create Toolbar
 #ifdef OriginalWin95
